@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,24 +13,19 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import gzip
 import json
 import os
 import sys
 import tempfile
 import unicodedata
+from typing import Dict, Tuple
 
 from hypothesis.configuration import mkdir_p, storage_directory
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.compat import hunichr
 
-if False:
-    from typing import Dict, Tuple
-
-    intervals = Tuple[Tuple[int, int], ...]
-    cache_type = Dict[Tuple[Tuple[str, ...], int, int, intervals], intervals]
+intervals = Tuple[Tuple[int, int], ...]
+cache_type = Dict[Tuple[Tuple[str, ...], int, int, intervals], intervals]
 
 
 def charmap_file():
@@ -70,10 +63,10 @@ def charmap():
             # https://github.com/HypothesisWorks/hypothesis/issues/2108 but it helps.
             category = unicodedata.category  # Local variable -> ~20% speedup!
             tmp_charmap = {}
-            last_cat = category(hunichr(0))
+            last_cat = category(chr(0))
             last_start = 0
             for i in range(1, sys.maxunicode + 1):
-                cat = category(hunichr(i))
+                cat = category(chr(i))
                 if cat != last_cat:
                     tmp_charmap.setdefault(last_cat, []).append([last_start, i - 1])
                     last_cat, last_start = cat, i
@@ -102,9 +95,9 @@ def charmap():
         # and that both elements of that tuple are integers.
         for vs in _charmap.values():
             ints = list(sum(vs, ()))
-            assert all([isinstance(x, int) for x in ints])
+            assert all(isinstance(x, int) for x in ints)
             assert ints == sorted(ints)
-            assert all([len(tup) == 2 for tup in vs])
+            assert all(len(tup) == 2 for tup in vs)
 
     assert _charmap is not None
     return _charmap
