@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,22 +13,10 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import math
+import struct
 
-from hypothesis.internal.compat import (
-    CAN_PACK_HALF_FLOAT,
-    quiet_raise,
-    struct_pack,
-    struct_unpack,
-)
-
-try:
-    import numpy
-except ImportError:
-    numpy = None
-
+from hypothesis.internal.compat import CAN_PACK_HALF_FLOAT
 
 # Format codes for (int, float) sized types, used for byte-wise casts.
 # See https://docs.python.org/3/library/struct.html#format-characters
@@ -44,25 +30,28 @@ STRUCT_FORMATS = {
 # There are two versions of this: the one that uses Numpy to support Python
 # 3.5 and earlier, and the elegant one for new versions.  We use the new
 # one if Numpy is unavailable too, because it's slightly faster in all cases.
-if numpy and not CAN_PACK_HALF_FLOAT:  # pragma: no cover
-
-    def reinterpret_bits(x, from_, to):
-        if from_ == b"!e":
-            arr = numpy.array([x], dtype=">f2")
-            if numpy.isfinite(x) and not numpy.isfinite(arr[0]):
-                quiet_raise(OverflowError("%r too large for float16" % (x,)))
-            buf = arr.tobytes()
-        else:
-            buf = struct_pack(from_, x)
-        if to == b"!e":
-            return float(numpy.frombuffer(buf, dtype=">f2")[0])
-        return struct_unpack(to, buf)[0]
+def reinterpret_bits(x, from_, to):
+    return struct.unpack(to, struct.pack(from_, x))[0]
 
 
-else:
+if not CAN_PACK_HALF_FLOAT:  # pragma: no cover
+    try:
+        import numpy
+    except ImportError:
+        pass
+    else:
 
-    def reinterpret_bits(x, from_, to):
-        return struct_unpack(to, struct_pack(from_, x))[0]
+        def reinterpret_bits(x, from_, to):  # noqa: F811
+            if from_ == b"!e":
+                arr = numpy.array([x], dtype=">f2")
+                if numpy.isfinite(x) and not numpy.isfinite(arr[0]):
+                    raise OverflowError("%r too large for float16" % (x,)) from None
+                buf = arr.tobytes()
+            else:
+                buf = struct.pack(from_, x)
+            if to == b"!e":
+                return float(numpy.frombuffer(buf, dtype=">f2")[0])
+            return struct.unpack(to, buf)[0]
 
 
 def float_of(x, width):
@@ -118,8 +107,8 @@ def next_up(value, width=64):
     assert isinstance(value, float)
     if math.isnan(value) or (math.isinf(value) and value > 0):
         return value
-    if value == 0.0:
-        value = 0.0
+    if value == 0.0 and is_negative(value):
+        return 0.0
     fmt_int, fmt_flt = STRUCT_FORMATS[width]
     # Note: n is signed; float_to_int returns unsigned
     fmt_int = fmt_int.lower()
